jacinle.cli.git
===============

.. automodule:: jacinle.cli.git

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      git_current_tracking_remote
      git_guard
      git_recent_logs
      git_remote_url
      git_revision_hash
      git_root
      git_status_full
      git_uncommitted_files
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: git_current_tracking_remote

.. autofunction:: git_guard

.. autofunction:: git_recent_logs

.. autofunction:: git_remote_url

.. autofunction:: git_revision_hash

.. autofunction:: git_root

.. autofunction:: git_status_full

.. autofunction:: git_uncommitted_files


